#include <arc/target.h>
#include <arc/standardbrokers.h>
#include <arc/notify.h>
#include <arc/mdsquery.h>
#include <arc/xrsl.h>

#include <list>

int main() {

	SetNotifyLevel(DEBUG);

	// Xrsl
	Xrsl xrsl("&(executable=/bin/echo)(arguments=\"hello, world\")(runtimeenvironment=\"ATLAS-8.0.5\")(CPUTime=50)");

	std::cout << "Xrsl: " << xrsl.str() << std::endl;
	try {
		PerformXrslValidation(xrsl);
	} catch(XrslError e) {
		notify(ERROR) << e.what() << std::endl;
		return 1;
	}

	// Getting queue info
	std::list<Queue> queueinfo = GetQueueInfo();
	std::list<Target> targets = ConstructTargets(queueinfo, xrsl);

	std::list<Target>::iterator it;
	std::cout << "Targets found:" << std::endl;
	if (queueinfo.size()==0) std::cout << "None" << std::endl;
	for (it = targets.begin(); it != targets.end(); it++) {
		std::cout << "Cluster: " << it->cluster.hostname << "  queue: " << it->name << "  cpu-frequency: ";
		if (it->cpu_freq!=-1) {
			std::cout << it->cpu_freq << std::endl;
		} else {
			std::cout << it->cluster.cpu_freq << std::endl;
		}
	}

	// Perform the standard brokering
	try {
		PerformStandardBrokering(targets);
	} catch(ARCLibError e) {
		std::cout << "Error: " << e.what() << std::endl;
	}

	std::cout << "Targets left after brokering: " << std::endl;
	if (targets.size()==0) std::cout << "None" << std::endl;

	for (it = targets.begin(); it != targets.end(); it++) {
		std::cout << "Cluster: " << it->cluster.hostname << "  queue: " << it->name << "  cpufrequency: ";
		if (it->cpu_freq!=-1) {
			std::cout << it->cpu_freq << std::endl;
		} else {
			std::cout << it->cluster.cpu_freq << std::endl;
		}
	}
}
