#ifndef TEST_CACHE_H_
#define TEST_CACHE_H_

#include "../file_cache.h"

#include <cppunit/extensions/HelperMacros.h>
#include <cppunit/extensions/TestFactoryRegistry.h>
#include <cppunit/ui/text/TestRunner.h>
#include <list>
#include <utime.h>

class FileCacheTest : public CPPUNIT_NS::TestFixture { 

  CPPUNIT_TEST_SUITE (FileCacheTest);
  CPPUNIT_TEST (testStart);
  CPPUNIT_TEST (testStop);
  CPPUNIT_TEST (testStopAndDelete);
  CPPUNIT_TEST (testLinkFile);
  CPPUNIT_TEST (testLinkFileLinkCache);
  CPPUNIT_TEST (testCopyFile);
  CPPUNIT_TEST (testFile);
  CPPUNIT_TEST (testRelease);
  CPPUNIT_TEST (testTwoCaches);
  CPPUNIT_TEST (testCreationDate);
  CPPUNIT_TEST (testValidityDate);
  CPPUNIT_TEST (testConstructor);
  CPPUNIT_TEST (testConstructorException);
  CPPUNIT_TEST (testInternal);
  CPPUNIT_TEST_SUITE_END ();

private:
  std::string _cache_dir;
  std::string _cache_job_dir;
  std::string _session_dir;
  std::string _url;
  std::string _jobid;
  uid_t _uid;
  gid_t _gid;
  FileCache *_fc1;
  /** A list of files to be removed after each test */
  std::list<std::string> _files;
  /** Create a file with the given size */
  bool _createFile(std::string filename, std::string text = "a");
  /** Return the contents of the given file */
  std::string _readFile(std::string filename);
  /** Convert an int to string */
  std::string _intToString(int i);
  
public: 
  void setUp();
  void tearDown();
  
protected:
  void testStart();
  void testStop();
  void testStopAndDelete();
  void testLinkFile();
  void testLinkFileLinkCache();
  void testCopyFile();
  void testFile();
  void testRelease();
  void testTwoCaches();
  void testCreationDate();
  void testValidityDate();
  void testConstructor();
  void testConstructorException();
  void testInternal();

};

#endif /*TEST_CACHE_H_*/
